@@ -4,7 +4,7 @@
 
  Author    : Peter Deak (hyperr@freemail.hu)
  License   : GPL
- Copyright : (C) 2003 Peter Deak
+ Copyright : (C) 2003 Peter Deak, 2010 Christoph Thielecke
 ****************************************************************************/
 
 #ifndef FINDDIALOG_H
@@ -13,29 +13,28 @@
 #include <qvariant.h>
 #include <qdialog.h>
 #include <qobject.h>
-//Added by qt3to4:
-#include <Q3GridLayout>
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
+#include <QGridLayout>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
 #include <QLabel>
-#include <Q3Frame>
+#include <QFrame>
 #include <QCloseEvent>
 // #include <pcre.h>
 #include <QRegExp>
 #include <QtGui/QDateTimeEdit>
+#include <QTreeWidget>
+#include <QTreeWidgetItem>
 
-class Q3VBoxLayout;
-class Q3HBoxLayout;
-class Q3GridLayout;
+class QVBoxLayout;
+class QHBoxLayout;
+class QGridLayout;
 class QCheckBox;
 class QComboBox;
-class Q3Frame;
+class QFrame;
 class QLabel;
 class QLineEdit;
-class Q3ListView;
-class Q3ListViewItem;
-class Q3HBoxLayout;
-class Q3VBoxLayout;
+class QHBoxLayout;
+class QVBoxLayout;
 class QSpinBox;
 class QPushButton;
 class DateTimeEdit;
@@ -77,6 +76,7 @@ class seekEngine : public QObject {
 		bool dirname;
 		bool filename;
 		bool comment;
+		bool find_category;
 		bool tartist;
 		bool ttitle;
 		bool talbum;
@@ -93,12 +93,13 @@ class seekEngine : public QObject {
 		
 		QString  media;
 		QString  owner;
+		QString category;
 		
 		QDateTime dateStart;
 		QDateTime dateEnd;
 		
-		float size_min;
-		float size_max;
+		double size_min;
+		double size_max;
 };
 
 /***********************************************************************/
@@ -107,23 +108,24 @@ class findDialog : public QDialog {
 		Q_OBJECT
 
 	public:
-		findDialog ( CdCatMainWidget* parent = 0, const char* name = 0, bool isFindDuplicates = false, bool modal = FALSE, Qt::WFlags fl = 0 );
+		findDialog ( CdCatMainWidget* parent = 0, const char* name = 0, bool isFindDuplicates = false, bool modal = FALSE, Qt::WFlags fl = Qt::WindowMinMaxButtonsHint );
 		~findDialog();
 		
 		
-		Q3Frame *input;
-		Q3HBoxLayout *h1, *h2, *h3, *h4;
-		Q3VBoxLayout *v1;
+		QFrame *input;
+		QHBoxLayout *h1, *h2, *h3, *h4;
+		QVBoxLayout *v1;
 		CdCatMainWidget *mainw;
 		QPushButton* buttonClose;
 		QPushButton* buttonExportResult;
 		QPushButton* buttonPrintResult;
-		Q3Frame* line1;
+		QFrame* line1;
 		QComboBox* cbOwner;
 		QComboBox* cbSin;
 		QPushButton* buttonCancel;
 		QPushButton* buttonOk;
-		QLabel* textLabel3;
+		QPushButton* buttonClearSearchResult;
+		QLabel* findTextLabel;
 		QLabel* textLabel1;
 		QLabel* textLabel2;
 		QLabel* textLabel5;
@@ -131,9 +133,10 @@ class findDialog : public QDialog {
 		QLabel* textLabel7;
 		QLabel* textLabel8;
 		QLabel* textLabelFindInArchive;
-		Q3Frame* line2;
-		Q3ListView* resultsl;
+		QFrame* line2;
+		QTreeWidget* resultsl;
 		QLineEdit* leText;
+		QLineEdit* leCategory;
 		QSpinBox* spSizeMin;
 		QSpinBox* spSizeMax;
 		QComboBox *cbSizeUnitMin;
@@ -142,6 +145,7 @@ class findDialog : public QDialog {
 		QDateTimeEdit* deDateStart;
 		QDateTimeEdit* deDateEnd;
 		QCheckBox* cbComment;
+		QCheckBox* cbCategory;
 		QCheckBox* cbFilename;
 		QCheckBox* cbDirname;
 		QCheckBox* cbTcomm;
@@ -157,6 +161,7 @@ class findDialog : public QDialog {
 		QCheckBox* cbSizeMax;
 		QCheckBox* cbUnsharpSearch;
 		QCheckBox* cbFindInArchive;
+		QCheckBox* cbKeepSearchResult;
 
 		bool use_unsharpsearch; // if unsharp match should be used
 		bool isFindDuplicates;
@@ -166,25 +171,27 @@ class findDialog : public QDialog {
 		void closeEvent ( QCloseEvent *ce );
 		void exportResult ( bool isPrint );
 		
-		Q3GridLayout* FindDialogBaseLayout;
-		Q3VBoxLayout* layout40;
-		Q3GridLayout* layout39;
-		Q3GridLayout* layout36;
-		Q3GridLayout* layout37;
-		Q3VBoxLayout* layout31;
-		Q3HBoxLayout* layout17;
-		Q3GridLayout* layout15;
-		Q3HBoxLayout* layout30;
-		Q3GridLayout* layout16;
-		Q3HBoxLayout* layout_size_min;
-		Q3HBoxLayout* layout_size_max;
-		Q3HBoxLayout* layout_find_in_archive;
+		QGridLayout* FindDialogBaseLayout;
+		QVBoxLayout* layout40;
+		QGridLayout* layout39;
+		QGridLayout* layout36;
+		QGridLayout* layout37;
+		QVBoxLayout* layout31;
+		QHBoxLayout* layout17;
+		QHBoxLayout* findLineLayout;
+		QGridLayout* layout15;
+		QHBoxLayout* layout30;
+		QGridLayout* layout16;
+		QHBoxLayout* layout_size_min;
+		QHBoxLayout* layout_size_max;
+		QHBoxLayout* layout_find_in_archive;
 		
 		QString searchFilepath;
 	
 	protected slots:
 		virtual void languageChange();
-		int select ( Q3ListViewItem *i );
+		int select ( QTreeWidgetItem *after, QTreeWidgetItem *before );
+		int select (QTreeWidgetItem *i, int col);
 		int closee ( void );
 		int cancele ( void );
 		int seeke ( void );
@@ -195,8 +202,10 @@ class findDialog : public QDialog {
 		void dateEndDoubleClicked();
 		void sizeMinClicked();
 		void sizeMaxClicked();
+		void categoryClicked();
 		void printResultClicked();
 		void exportResultClicked();
+		void clearSearchResultClicked();
 
 };
 
