@@ -13,20 +13,21 @@
 #include <qvariant.h>
 #include <qdialog.h>
 #include <qstring.h>
-//Added by qt3to4:
-#include <Q3VBoxLayout>
-#include <Q3GridLayout>
-#include <Q3HBoxLayout>
+#include <QVBoxLayout>
+#include <QGridLayout>
+#include <QHBoxLayout>
 #include <QLabel>
 
-class Q3VBoxLayout;
-class Q3HBoxLayout;
-class Q3GridLayout;
+#include "guibase.h"
+
+class QGridLayout;
 class QPushButton;
 class QTabWidget;
 class QWidget;
 class QLabel;
-class Q3TextBrowser;
+class QTextBrowser;
+class QListView;
+class QTableWidget;
 
 class InfoDialog : public QDialog {
     Q_OBJECT
@@ -38,17 +39,17 @@ public:
     QPushButton* closeButton;
     QTabWidget* tabWidget2;
     QWidget* tab;
-    QLabel* textLabel1;
     QWidget* tab_2;
-    Q3TextBrowser* textBrowser1;
+    QTextBrowser* textBrowser1;
+    QTextBrowser* textBrowser2;
     QWidget* TabPage;
-    Q3TextBrowser* textThanx;
+    QTextBrowser* textThanx;
 
 protected:
-    Q3GridLayout* helpDialogLayout;
-    Q3GridLayout* tabLayout;
-    Q3GridLayout* tabLayout_2;
-    Q3GridLayout* TabPageLayout;
+    QGridLayout* helpDialogLayout;
+    QGridLayout* tabLayout;
+    QGridLayout* tabLayout_2;
+    QGridLayout* TabPageLayout;
     QString infotext;
     QString contribution;
     QString license;
@@ -58,4 +59,20 @@ protected slots:
 
 };
 
+class KeyBindingDialog : public QDialog {
+    Q_OBJECT
+
+public:
+    KeyBindingDialog ( GuiSlave *gs, QWidget* parent = 0, const char* name = 0, bool modal = FALSE, Qt::WFlags fl = 0 );
+    ~KeyBindingDialog();
+
+    QGridLayout* keyBindingDialogLayout;
+    QLabel* TitleLabel;
+    QPushButton* closeButton;
+    QTableWidget *KeyBindingsTableWidget;
+
+protected slots:
+    virtual void languageChange();
+};
+
 #endif // HELPDIALOG_H
