@@ -12,18 +12,20 @@
 #include <qvariant.h>
 #include <qpixmap.h>
 #include <qdialog.h>
-//Added by qt3to4:
-#include <Q3VBoxLayout>
-#include <Q3GridLayout>
-#include <Q3HBoxLayout>
+#include <QVBoxLayout>
+#include <QGridLayout>
+#include <QHBoxLayout>
 #include <QTextBrowser>
 #include <QLabel>
+ #include <QFontComboBox>
 
-class Q3VBoxLayout;
-class Q3HBoxLayout;
-class Q3GridLayout;
+#include "config.h"
+
+class QVBoxLayout;
+class QHBoxLayout;
+class QGridLayout;
 class QPushButton;
-class Q3TextBrowser;
+class QTextBrowser;
 class QToolButton;
 class QLabel;
 class Node;
@@ -32,7 +34,7 @@ class ShowContent : public QDialog {
     Q_OBJECT
 
 public:
-    ShowContent ( Node *node, bool isCategory=false, QWidget* parent = 0, const char* name = 0, bool modal = FALSE, Qt::WFlags fl = 0 );
+    ShowContent ( Node *node, bool isCategory=false, CdCatConfig *cconfig=NULL, QWidget* parent = 0, const char* name = 0, bool modal = FALSE, Qt::WFlags fl = 0 );
     ~ShowContent();
 
     QPushButton* closeButton;
@@ -40,21 +42,24 @@ public:
     QToolButton* saveButton;
     QTextBrowser* textBrowser;
     QLabel* sizel;
+    QFontComboBox *comboFont;
 
 public slots:
     int deletenode ( void );
     int savenode ( void );
 
 protected:
-    Q3GridLayout* ShowContentLayout;
-    Q3HBoxLayout* layout1;
+    QGridLayout* ShowContentLayout;
+    QHBoxLayout* layout1;
 
 protected slots:
-    virtual void languageChange();
+    void languageChange();
+    void setCurrentFont(const QFont &);
 
 private:
     Node *parentnode,*mynode;
     bool isCategory;
+    CdCatConfig *cconfig;
 
 };
 
